package com.example.bmicalculator

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.*
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            BMICalculatorApp()
        }
    }
}

@Composable
fun BMICalculatorApp() {
    var weight by remember { mutableStateOf("") }
    var height by remember { mutableStateOf("") }
    var bmi by remember { mutableStateOf(0.0) }
    var category by remember { mutableStateOf("") }

    fun calculateBMI() {
        val weightValue = weight.toDoubleOrNull() ?: 0.0
        val heightValue = height.toDoubleOrNull()?.div(100) ?: 0.0
        if (weightValue > 0 && heightValue > 0) {
            bmi = weightValue / (heightValue * heightValue)
            category = when {
                bmi < 18.5 -> "Underweight"
                bmi < 24.9 -> "Normal"
                bmi < 29.9 -> "Overweight"
                else -> "Obese"
            }
        }
    }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.spacedBy(8.dp)
    ) {
        Text(text = "BMI Calculator", fontSize = 24.sp)
        OutlinedTextField(
            value = weight,
            onValueChange = { weight = it },
            label = { Text("Weight (kg)") },
            modifier = Modifier.fillMaxWidth()
        )
        OutlinedTextField(
            value = height,
            onValueChange = { height = it },
            label = { Text("Height (cm)") },
            modifier = Modifier.fillMaxWidth()
        )
        Button(
            onClick = { calculateBMI() },
            modifier = Modifier.fillMaxWidth()
        ) {
            Text("Calculate")
        }
        if (bmi > 0) {
            Text(text = "BMI: ${String.format("%.2f", bmi)}", fontSize = 20.sp)
            Text(text = "Category: $category", fontSize = 20.sp)
        }
    }
}
